# -*- coding: utf-8 -*-
"""classify package.

Classification tools using machine learning methods.

API:

* NaiveBayesClassifier (class): Classifier which uses naive bayes algorithm.
* [To-Do] KNNClassifier (class): Classifier which uses KNN algorithm.
* [To-Do] DecisionTreeClassifier (class): Classifier which uses decision tree algorithm.

"""

from ._naivebayes import NaiveBayesClassifier
